==> Jord-0.2.8.tar.gz: Jord-0.2.8/README.md <==
<!--![header](.github/images/header.png)-->

<p align="center">
  <img src=".github/images/header.svg" alt='header' />
</p>

<h1 align="center">Jord</h1>

<!--# Jord-->

| [![Build Status](https://travis-ci.org/automaps/jord.svg?branch=master)](https://travis-ci.org/automaps/jord) | [![Coverage Status](https://coveralls.io/repos/github/automaps/jord/badge.svg?branch=master)](https://coveralls.io/github/automaps/jord?branch=master) | [![GitHub Issues](https://img.shields.io/github/issues/automaps/jord.svg?style=flat)](https://github.com/automaps/jord/issues) | [![GitHub Forks](https://img.shields.io/github/forks/automaps/jord.svg?style=flat)](https://github.com/automaps/jord/network) | [![GitHub Stars](https://img.shields.io/github/stars/automaps/jord.svg?style=flat)](https://github.com/automaps/jord/stargazers) | [![GitHub License](https://img.shields.io/github/license/automaps/jord.svg?style=flat)](https://github.com/automaps/jord/blob/master/LICENSE.md) |
|--------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------|-------------------------------------------------------------------------------------------------------------------------------|----------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------|

<p align="center" width="100%">
  <a href="https://www.python.org/">
    <img alt="python" src=".github/images/python.svg" height="40" align="left">
  </a>
  <a href="http://pytorch.org/" style="float: right;">
    <img alt="pytorch" src=".github/images/pytorch.svg" height="40" align="right" >
  </a>
</p>
<p align="center" width="100%">
  <a href="http://www.numpy.org/">
    <img alt="numpy" src=".github/images/numpy.svg" height="40" align="left">
  </a>
  <a href="https://github.com/tqdm/tqdm" style="float:center;">
    <img alt="tqdm" src=".github/images/tqdm.gif" height="40" align="center">
  </a>
</p>

# Authors

* **Christian Heider Nielsen** - [cnheider](https://github.com/cnheider)
* [Other contributors](https://github.com/automaps/jord/contributors)

==> Jord-0.5.0.tar.gz: Jord-0.5.0/README.md <==
<!--![header](.github/images/header.png)-->

<p align="center">
  <img src=".github/images/header.svg" alt='header' />
</p>

<h1 align="center">Jord</h1>

<!--# Jord-->

| [![Build Status](https://travis-ci.org/automaps/jord.svg?branch=master)](https://travis-ci.org/automaps/jord) | [![Coverage Status](https://coveralls.io/repos/github/automaps/jord/badge.svg?branch=master)](https://coveralls.io/github/automaps/jord?branch=master) | [![GitHub Issues](https://img.shields.io/github/issues/automaps/jord.svg?style=flat)](https://github.com/automaps/jord/issues) | [![GitHub Forks](https://img.shields.io/github/forks/automaps/jord.svg?style=flat)](https://github.com/automaps/jord/network) | [![GitHub Stars](https://img.shields.io/github/stars/automaps/jord.svg?style=flat)](https://github.com/automaps/jord/stargazers) | [![GitHub License](https://img.shields.io/github/license/automaps/jord.svg?style=flat)](https://github.com/automaps/jord/blob/master/LICENSE.md) |
|---------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------|-------------------------------------------------------------------------------------------------------------------------------|----------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------|

<p align="center" width="100%">
  <a href="https://www.python.org/">
    <img alt="python" src=".github/images/python.svg" height="40" align="left">
  </a>
  <a href="http://pytorch.org/" style="float: right;">
    <img alt="pytorch" src=".github/images/pytorch.svg" height="40" align="right" >
  </a>
</p>
<p align="center" width="100%">
  <a href="http://www.numpy.org/">
    <img alt="numpy" src=".github/images/numpy.svg" height="40" align="left">
  </a>
  <a href="https://github.com/tqdm/tqdm" style="float:center;">
    <img alt="tqdm" src=".github/images/tqdm.gif" height="40" align="center">
  </a>
</p>

# Authors

* **Christian Heider Lindbjerg** - [cnheider](https://github.com/cnheider)
* [Other contributors](https://github.com/automaps/jord/contributors)
